@@ -3,12 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: An algorithmic MIDI drummer
 
-our $VERSION = '0.0808';
+our $VERSION = '0.0810';
 
 use strict;
 use warnings;
 
-use MIDI::Simple;
+use MIDI::Simple ();
 use Music::Duration;
 
 BEGIN {
@@ -19,15 +19,15 @@ BEGIN {
         q => { number =>  4, ordinal =>  '4th', name => 'quarter' },
         e => { number =>  8, ordinal =>  '8th', name => 'eighth' },
         s => { number => 16, ordinal => '16th', name => 'sixteenth' },
-        y => { number => 32, ordinal => '32nd', name => 'thirtysecond' },
-        x => { number => 64, ordinal => '64th', name => 'sixtyfourth' },
-        o => { number => 128, ordinal => '128th', name => 'onetwentyeighth' },
+        x => { number => 32, ordinal => '32nd', name => 'thirtysecond' },
+        y => { number => 64, ordinal => '64th', name => 'sixtyfourth' },
+        z => { number => 128, ordinal => '128th', name => 'onetwentyeighth' },
     };
 
     # Add constants for each known duration.
     for my $n (keys %MIDI::Simple::Length) {
         # Get the duration part of the note name.
-        my $name = $n =~ /([whqesyxo])n$/ ? $1 : '';
+        my $name = $n =~ /([whqesxyz])n$/ ? $1 : '';
 
         if ($name) {
             # Create a meaningful prefix for the named constant.
@@ -563,7 +563,7 @@ MIDI::Simple::Drummer - An algorithmic MIDI drummer
 
 =head1 VERSION
 
-version 0.0808
+version 0.0810
 
 =head1 SYNOPSIS
 
@@ -1091,7 +1091,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
